"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.handler = exports.help = exports.commandNames = exports.shorthands = exports.cliOptionsTypes = exports.rcOptionsTypes = void 0;
const fs_1 = __importDefault(require("fs"));
const os_1 = __importDefault(require("os"));
const path_1 = __importDefault(require("path"));
const cli_utils_1 = require("@pnpm/cli-utils");
const logger_1 = __importDefault(require("@pnpm/logger"));
const render_help_1 = __importDefault(require("render-help"));
const setupOnWindows_1 = require("./setupOnWindows");
const rcOptionsTypes = () => ({});
exports.rcOptionsTypes = rcOptionsTypes;
const cliOptionsTypes = () => ({});
exports.cliOptionsTypes = cliOptionsTypes;
exports.shorthands = {};
exports.commandNames = ['setup'];
function help() {
    return (0, render_help_1.default)({
        description: 'Sets up pnpm',
        descriptionLists: [],
        url: (0, cli_utils_1.docsUrl)('setup'),
        usages: ['pnpm setup'],
    });
}
exports.help = help;
function getExecPath() {
    if (process['pkg'] != null) {
        // If the pnpm CLI was bundled by vercel/pkg then we cannot use the js path for npm_execpath
        // because in that case the js is in a virtual filesystem inside the executor.
        // Instead, we use the path to the exe file.
        return process.execPath;
    }
    return (require.main != null) ? require.main.filename : process.cwd();
}
function copyCli(currentLocation, targetDir) {
    const newExecPath = path_1.default.join(targetDir, path_1.default.basename(currentLocation));
    if (path_1.default.relative(newExecPath, currentLocation) === '')
        return;
    logger_1.default.info({
        message: `Copying pnpm CLI from ${currentLocation} to ${newExecPath}`,
        prefix: process.cwd(),
    });
    fs_1.default.mkdirSync(targetDir, { recursive: true });
    fs_1.default.copyFileSync(currentLocation, newExecPath);
}
async function handler(opts) {
    const currentShell = typeof process.env.SHELL === 'string' ? path_1.default.basename(process.env.SHELL) : null;
    const execPath = getExecPath();
    if (execPath.match(/\.[cm]?js$/) == null) {
        copyCli(execPath, opts.pnpmHomeDir);
    }
    const updateOutput = await updateShell(currentShell, opts.pnpmHomeDir);
    return `${updateOutput}

Setup complete. Open a new terminal to start using pnpm.`;
}
exports.handler = handler;
async function updateShell(currentShell, pnpmHomeDir) {
    switch (currentShell) {
        case 'bash': {
            const configFile = path_1.default.join(os_1.default.homedir(), '.bashrc');
            return setupShell(configFile, pnpmHomeDir);
        }
        case 'zsh': {
            const configFile = path_1.default.join(os_1.default.homedir(), '.zshrc');
            return setupShell(configFile, pnpmHomeDir);
        }
        case 'fish': {
            return setupFishShell(pnpmHomeDir);
        }
    }
    if (process.platform === 'win32') {
        return (0, setupOnWindows_1.setupWindowsEnvironmentPath)(pnpmHomeDir);
    }
    return 'Could not infer shell type.';
}
async function setupShell(configFile, pnpmHomeDir) {
    const content = `export PNPM_HOME="${pnpmHomeDir}"
export PATH="$PNPM_HOME:$PATH"
`;
    if (!fs_1.default.existsSync(configFile)) {
        await fs_1.default.promises.writeFile(configFile, content, 'utf8');
        return `Created ${configFile}`;
    }
    const configContent = await fs_1.default.promises.readFile(configFile, 'utf8');
    if (configContent.includes('PNPM_HOME')) {
        return `PNPM_HOME is already in ${configFile}`;
    }
    await fs_1.default.promises.appendFile(configFile, `\n${content}`, 'utf8');
    return `Updated ${configFile}`;
}
async function setupFishShell(pnpmHomeDir) {
    const configFile = path_1.default.join(os_1.default.homedir(), '.config/fish/config.fish');
    const content = `set -gx PNPM_HOME "${pnpmHomeDir}"
set -gx PATH "$PNPM_HOME" $PATH
`;
    if (!fs_1.default.existsSync(configFile)) {
        await fs_1.default.promises.writeFile(configFile, content, 'utf8');
        return `Created ${configFile}`;
    }
    const configContent = await fs_1.default.promises.readFile(configFile, 'utf8');
    if (configContent.includes('PNPM_HOME')) {
        return `PNPM_HOME is already in ${configFile}`;
    }
    await fs_1.default.promises.appendFile(configFile, `\n${content}`, 'utf8');
    return `Updated ${configFile}`;
}
//# sourceMappingURL=setup.js.map