"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.setupWindowsEnvironmentPath = void 0;
const path_1 = require("path");
const execa_1 = __importDefault(require("execa"));
async function setupWindowsEnvironmentPath(pnpmHomeDir) {
    const pathRegex = /^ {4}(?<name>PATH) {4}(?<type>\w+) {4}(?<data>.*)$/gim;
    const pnpmHomeRegex = /^ {4}(?<name>PNPM_HOME) {4}(?<type>\w+) {4}(?<data>.*)$/gim;
    const regKey = 'HKEY_CURRENT_USER\\Environment';
    const queryResult = await (0, execa_1.default)('reg', ['query', regKey]);
    if (queryResult.failed) {
        return 'Win32 registry environment values could not be retrieved';
    }
    const queryOutput = queryResult.stdout;
    const pathValueMatch = [...queryOutput.matchAll(pathRegex)];
    const homeValueMatch = [...queryOutput.matchAll(pnpmHomeRegex)];
    let commitNeeded = false;
    let homeDir = pnpmHomeDir;
    const logger = [];
    if (homeValueMatch.length === 1) {
        homeDir = homeValueMatch[0].groups.data;
        logger.push(`Currently 'PNPM_HOME' is set to '${homeDir}'`);
    }
    else {
        logger.push(`Setting 'PNPM_HOME' to value '${homeDir}'`);
        const addResult = await (0, execa_1.default)('reg', ['add', regKey, '/v', 'PNPM_HOME', '/t', 'REG_EXPAND_SZ', '/d', homeDir, '/f']);
        if (addResult.failed) {
            logger.push(`\t${addResult.stderr}`);
        }
        else {
            commitNeeded = true;
            logger.push(`\t${addResult.stdout}`);
        }
    }
    if (pathValueMatch.length === 1) {
        const pathData = pathValueMatch[0].groups.data;
        if (pathData == null || pathData.trim() === '') {
            logger.push('Current PATH is empty. No changes to this environment variable are applied');
        }
        else {
            const homeDirPath = path_1.win32.parse(path_1.win32.normalize(homeDir));
            if (pathData
                .split(path_1.win32.delimiter)
                .map(p => path_1.win32.normalize(p))
                .map(p => path_1.win32.parse(p))
                .map(p => `${p.dir}${path_1.win32.sep}${p.base}`.toUpperCase())
                .filter(p => p !== '')
                .includes(`${homeDirPath.dir}${path_1.win32.sep}${homeDirPath.base}`.toUpperCase())) {
                logger.push('PATH already contains PNPM_HOME');
            }
            else {
                logger.push('Updating PATH');
                const addResult = await (0, execa_1.default)('reg', ['add', regKey, '/v', pathValueMatch[0].groups.name, '/t', 'REG_EXPAND_SZ', '/d', `${homeDir}${path_1.win32.delimiter}${pathData}`, '/f']);
                if (addResult.failed) {
                    logger.push(`\t${addResult.stderr}`);
                }
                else {
                    commitNeeded = true;
                    logger.push(`\t${addResult.stdout}`);
                }
            }
        }
    }
    else {
        logger.push('Current PATH is not set. No changes to this environment variable are applied');
    }
    if (commitNeeded) {
        await (0, execa_1.default)('setx', ['PNPM_HOME', homeDir]);
    }
    return logger.join('\n');
}
exports.setupWindowsEnvironmentPath = setupWindowsEnvironmentPath;
//# sourceMappingURL=setupOnWindows.js.map